
Changelog
=========

0.2.0 (2020-04-28)
------------------

* Change ownership of repo to Smithsonian GitHub team
* Incorporate `.tor` file parsing

0.1.3 (2020-03-10)
------------------

* Packaging changes to allow automated pushes to PyPI and TestPyPI

0.1.2 (2020-03-10)
------------------

* More bug fixes to work with older GRASP 10.0 cut files

0.1.1 (2020-03-18)
------------------

* Initial bug fixes to work with older GRASP 10.0 cut files

0.1.0 (2020-03-18)
------------------

* Initial attempts to work with older GRASP 10.0 files

0.0.1 (2020-02-04)
------------------

* Initial creation from PaulKGrimes/GraspFile and PaulKGrimes/CHAMPEdxFile repos
